﻿/*!
 * The Image Components ImgBarCoder class.
 * Creates a new ImgBarCoder component instance.
 * @class
 * @author   Image Components <info@imagecomponents.net> <https://www.imagecomponents.net>
 * @license  Copyright © ImageComponents 2023
 */
var ImgBarCoder = function () {

    /**
    * ImgBarCoder ImgEdit Component Property
    * @type {ImgEdit}
    * @property {ImgEdit} ImgEditComponent Gets or sets the ImgEdit container component.
    * @param {ImgEdit} value Sets the ImgEditComponent value.
    * @return {ImgEdit} Gets the ImgEditComponent value.
    */
    this.ImgEditComponent = null;
    /**
    * ImgBarCoder Encoded Barcode Result Property
    * @type {ImgBarCoder.EncodedBarcodeResult}
    * @property {ImgBarCoder.BarcodesResult} EncodedBarcodeResult Gets the final encoded barcode result.
    * @return {ImgBarCoder.EncodedBarcodeResult} Gets the final encoded barcode result.
    */
    this.EncodedBarcodeResult = null;
    /**
    * ImgBarCoder Barcode Value Property
    * @type {String}
    * @property {ImgBarCoder.BarcodeValue} BarcodeValue Gets or sets the string value to encode.
    * @param {String} value Sets the string value to encode.
    * @return {String} Gets the string value to encode.
    */
    this.BarcodeValue = '';
    /**
    * ImgBarCoder Header Value Property
    * @type {String}
    * @property {String} HeaderValue Gets or sets the selected image page.
    * @param {String} value Sets the SelectedPage value.
    * @return {String} Gets the SelectedPage value.
    */
    this.HeaderValue = '';
    /**
    * ImgBarCoder EncodedValue Property
    * @type {String}
    * @property {String} EncodedValue Gets the binary barcode encoded value.
    * @return {String} Gets the binary barcode encoded value.
    */
    this.EncodedValue = '';
    /**
    * ImgBarCoder Encode Barcode Output Type Property
    * @type {ImgBarCoder.ICImageOutputType}
    * @property {ImgBarCoder.ICImageOutputType} EncodeBarcodeOutputType Gets or sets the barcode image output type.
    * @param {ImgBarCoder.ICImageOutputType} value Sets the barcode image output type.
    * @return {ImgBarCoder.ICImageOutputType} Gets the barcode image output type.
    */
    this.EncodeBarcodeOutputType = null;
    /**
    * ImgBarCoder Encode Barcode Output Format Property
    * @type {ImgBarCoder.ICImageOutputFormat}
    * @property {ImgBarCoder.ICImageOutputFormat} EncodeBarcodeOutputFormat  Gets or sets the barcode image output format.
    * @param {ImgBarCoder.ICImageOutputFormat} value Sets the barcode image output format.
    * @return {ImgBarCoder.ICImageOutputFormat} Gets the barcode image output format.
    */
    this.EncodeBarcodeOutputFormat = null;
    /**
    * ImgBarCoder Encode Barcode Output Compression Property
    * @type {ImgBarCoder.ICImageCompression}
    * @property {ImgBarCoder.ICImageCompression} EncodeBarcodeOutputCompression Gets or sets the barcode image output compression.
    * @param {ImgBarCoder.ICImageCompression} value Sets the barcode image output compression.
    * @return {ImgBarCoder.ICImageCompression} Gets the barcode image output compression.
    */
    this.EncodeBarcodeOutputCompression = 0;
    /**
    * ImgBarCoder Enable Check Digit Property
    * @type {ImgBarCoder.ICImageBarcodeType}
    * @property {ImgBarCoder.ICImageBarcodeType} EncodeBarcodeType Gets or sets the barcode type to encode.
    * @param {ImgBarCoder.ICImageBarcodeType} value Sets the barcode type to encode.
    * @return {ImgBarCoder.ICImageBarcodeType} Gets the barcode type to encode.
    */
    this.EncodeBarcodeType = 0;
    /**
      * ImgBarCoder Fore Color Property
      * @type {ImgBarCoder.ICColor}
      * @property {ImgBarCoder.ICColor} ForeColor Gets or sets the barcode bars, header and footer text fore-color.
      * @param {ImgBarCoder.ICColor} value Sets the barcode bars, header and footer text fore-color.
      * @return {ImgBarCoder.ICColor} Gets the barcode bars, header and footer text fore-color.
      */
    this.ForeColor = null;
    /**
      * ImgBarCoder Back Color Property
      * @type {ImgBarCoder.ICColor}
      * @property {ImgBarCoder.ICColor} BackColor Gets or sets the encoded barcode image back-color.
      * @param {ImgBarCoder.ICColor} value Sets the encoded barcode image back-color.
      * @return {ImgBarCoder.ICColor} Gets the encoded barcode image back-color.
      */
    this.BackColor = null;
    /**
      * ImgBarCoder Barcode Width Property
      * @type {Number}
      * @property {Number} BarcodeWidth Gets or sets the encoded barcode image width.
      * @param {Number} value Sets the encoded barcode image width.
      * @return {Number} Gets the encoded barcode image width.
      */
    this.BarcodeWidth = 400;
    /**
      * ImgBarCoder Barcode Height Property
      * @type {Number}
      * @property {Number} BarcodeHeight Gets or sets the encoded barcode image height.
      * @param {Number} value Sets the encoded barcode image height.
      * @return {Number} Gets the encoded barcode image height.
      */
    this.BarcodeHeight = 200;
    /**
     * ImgBarCoder Show Footer Property
     * @type {Boolean}
     * @property {Boolean} ShowFooter Gets or sets the visibility of the footer value.
     * @param {Boolean} value Sets the visibility of the footer value.
     * @return {Boolean} Gets the visibility of the footer value.
     */
    this.ShowFooter = null;
    /**
     * ImgBarCoder Show Header Property
     * @type {Boolean}
     * @property {Boolean} ShowHeader Gets or sets the visibility of the header value.
     * @param {Boolean} value Sets the visibility of the header value.
     * @return {Boolean} Gets the visibility of the header value.
     */
    this.ShowHeader = null;
    /**
     * ImgBarCoder Manufacturer Code Property
     * @type {String}
     * @property {String} ManufacturerCode Gets the EAN8 AND EAN13 manufacturer code.
     * @return {String} Gets the EAN8 AND EAN13 manufacturer code.
     */
    this.ManufacturerCode = null;
    /**
    * ImgBarCoder Version Property
    * @readonly
    * @type {String}
    * @property {String} Version Gets the image bar-coder component version.
    * @return {String} Gets the Version value.
    */
    this.Version = null;

    /**
    * Encode started add event handler.
    * Adds the encode started event handler.
    * @function
    * @param {function(ImgBarCoder,ImgBarCoder.EncodedBarcodeResult)} h Event handler function.
    */
    this.add_EncodeStarted = function (h) {
    };
    /**
    * Encode started remove event handler.
    * Removes the encode started event handler.
    * @function
    * @param {function(ImgBarCoder,ImgBarCoder.EncodedBarcodeResult)} h Event handler function.
    */
    this.remove_EncodeStarted = function (h) {
    };
    /**
    * Occurs when the barcode encode is started.
    * @event ScanResult Raises the encode started event handler.
    * @param {ImgBarCoder} s The ImgBarCoder component object.
    * @param {ImgBarCoder.EncodedBarcodeResult} e The barcode encode value.
    */
    this.EncodeStarted = function (s, e) {
    };

    /**
    * Encode finished add event handler.
    * Adds the encode finished event handler.
    * @function
    * @param {function(ImgBarCoder,ImgBarCoder.ICBarDecoderResultArgs)} h Event handler function.
    */
    this.add_EncodeFinished = function (h) {
    };
    /**
    * Encode finished remove event handler.
    * Removes the encode finished event handler.
    * @function
    * @param {function(ImgBarCoder,ImgBarCoder.ICBarDecoderResultArgs)} h Event handler function.
    */
    this.remove_EncodeFinished = function (h) {
    };
    /**
    * Occurs when the barcode encode is finished.
    * @event EncodeFinished Raises the encode finished event handler.
    * @param {ImgBarCoder} s The ImgBarCoder component object.
    * @param {ImgBarCoder.ICBarDecoderResultArgs} e The barcodes result finish value.
    */
    this.EncodeFinished = function (s, e) {
    };
    /**
    * Request started add event handler.
    * Adds the request started event handler.
    * @function
    * @param {function(ImgBarCoder)} h Event handler function.
    */
    this.add_RequestStarted = function (h) {
    };
    /**
    * Request started remove event handler.
    * Remove the request started event handler.
    * @function
    * @param {function(ImgBarCoder)} h Event handler function.
    */
    this.remove_RequestStarted = function (h) {
    };
    /**
    * Occurs every started web service request.
    * @event RequestStarted Raises the request started event handler.
    * @param {ImgBarCoder} s The ImgScan component object.
    */
    this.RequestStarted = function (s) {
    };
    /**
    * Request finished add event handler.
    * Adds the request finished event handler.
    * @function
    * @param {function(ImgBarCoder)} h Event handler function.
    */
    this.add_RequestFinished = function (h) {
    };
    /**
    * Request finished remove event handler.
    * Removes the request finished event handler.
    * @function
    * @param {function(ImgBarCoder)} h Event handler function.
    */
    this.remove_RequestFinished = function (h) {
    };
    /**
    * Occurs every finished web service request.
    * @event RequestFinished Raises the request finished event handler.
    * @param {ImgBarCoder} s The ImgScan component object.
    */
    this.RequestFinished = function (s) {
    };
    /**
    * Error occurred add event handler.
    * Adds the error occurred add event handler.
    * @function
    * @param {function(ImgBarCoder,ImgBarCoder.ICErrorOccurredArgs)} h Event handler function.
    */
    this.add_ErrorOccurred = function (h) {
    };
    /**
    * Error occurred remove event handler.
    * Removes the error occurred add event handler.
    * @function
    * @param {function(ImgBarCoder,ImgBarCoder.ICErrorOccurredArgs)} h Event handler function.
    */
    this.remove_ErrorOccurred = function (h) {
    };
    /**
    * Occurs every time one error is raised.
    * @event ErrorOccurred Raises the error occurred event handler.
    * @param {ImgBarCoder} s The ImgBarCoder component object.
    * @param {ImgBarCoder.ICErrorOccurredArgs} e The control name, method and description that raised the error.
    */
    this.ErrorOccurred = function (s, e) {
    };
};

/**
* ImgBarCoder Add Event Listener Method
* Adds a listener to an event by name.
* @function
* @param {String} eventName The event name.
* @param {Function} handler The event callback method to be raised.
*/
ImgBarCoder.prototype.addEventListener = function (eventName, handler) {
};

/**
* ImgBarCoder Remove Event Listener Method
* Removes the listener of an event by name.
* @function
* @param {String} eventName The event name.
* @param {Function} handler The event callback method to be removed from the event.
*/
ImgBarCoder.prototype.removeEventListener = function (eventName, handler) {
};

/**
* ImgBarCoder Encode Barcode Method
* Encodes one specified character string to a barcode base64 image object.
* @function
*/
ImgBarCoder.prototype.EncodeBarcode = function () {
};

/**
* ImgBarCoder Dispose Method
* Releases all the in use ImgBarCoder memory objects.
* @function
*/
ImgBarCoder.prototype.Dispose = function () {
};

/**
* Image Barcode type enumeration.
* @readonly
* @enum {number}
*/
ImgBarCoder.ICImageBarcodeType = {
    /** None or auto barcode type. */
    AUTO: 0,
    /** Code11 barcode type. */
    CODE11: 3,
    /** Code39 extended barcode type. */
    CODE39EXT: 13,
    /** CODABAR 1D barcode type. */
    CODABAR: 2,
    /** CODE 39 1D barcode type. */
    CODE39: 4,
    /** CODE 93 1D barcode type. */
    CODE93: 8,
    /** CODE 128 1D barcode type. */
    CODE128: 16,
    /** EAN-8 1D barcode type. */
    EAN8: 64,
    /** EAN-13 1D barcode type. */
    EAN13: 128,
    /** Interleaved 2 of 5 1D barcode type. */
    ILV2OF5: 256,
    /** PDF417 barcode type. */
    PDF417: 1024,
    /** QR CODE 2D barcode barcode type. */
    QRCODE: 2048,
    /** UPC-A 1D barcode type. */
    UPCA: 16384,
    /** UPC-E 1D barcode type. */
    UPCE: 32768
};

/**
* Image output format enumeration.
* @readonly
* @enum {number}
*/
ImgBarCoder.ICImageOutputFormat = {
    /** Unknown output format.  */
    UNKNOWN: -1,
    /** Default output format.  */
    DEFAULT: -2,
    /** Windows or OS/2 Bitmap File (*.BMP).  */
    BMP: 0,
    /** Windows Icon (*.ico).  */
    ICO: 1,
    /** JPEG output format. */
    JPEG: 2,
    /** JPEG Network Graphics (*.jng).  */
    JNG: 3,
    /** Portable Bitmap (ASCII) (*.pbm).  */
    PBM: 7,
    /** Portable Graymap (ASCII) (*.pgm).  */
    PGM: 11,
    /** PNG output format. */
    PNG: 13,
    /** Portable Pixelmap (ASCII) (*.ppm).  */
    PPM: 14,
    /** truevision Targa files (*.tga, *.targa).  */
    TARGA: 17,
    /** TIFF output format. */
    TIFF: 18,
    /** Wireless Bitmap (*.wbmp).  */
    WBMP: 19,
    /** X11 Pixmap Format (*.xpm).  */
    XPM: 23,
    /** GIF output format.  */
    GIF: 25,
    /** JPEG-2000 format (*.j2k, *.j2c).  */
    J2K: 30,
    /** Portable FloatMap (*.pfm).  */
    PFM: 32,
    /** Web P files (*.webp*).  */
    WEBP: 35,
    /** JPEG-XR files (*.jxr*).  */
    JXR: 36,
    /** PDF image output format.  */
    PDF: 40
};

/**
* Image Compression enumeration.
* @readonly
* @enum {number}
*/
ImgBarCoder.ICImageCompression = {
    /** Unknown compression.  */
    UNKNOWN: -1,
    /** Default compression.  */
    DEFAULT: 0,
    /** None save compression.  */
    NONE: 1,
    /** RLE save compression.  */
    RLE: 2,
    /** CCITT3 save compression.  */
    CCITT3: 3,
    /** CCITT4 save compression.  */
    CCITT4: 4,
    /** LZW save compression.  */
    LZW: 5,
    /** Old JPEG save compression.  */
    OJPEG: 6,
    /** JPEG save compression.  */
    JPEG: 7,
    /** Deflate compression, as recognized by Adobe.*/
    ADOBE_DEFLATE: 8,
    /** DEFLATE image compression.*/
    DEFLATE: 32946,
    /** PACKBITS image compression.*/
    PACKBITS: 32773
};

/**
* Image output type enumeration.
* @readonly
* @enum {number}
*/
ImgBarCoder.ICImageOutputType = {
    /** Base64 image output type.  */
    Base64: 3
};

/*!
 * The Image Components Encoded Barcode Result Class.
 * Creates a new barcode encode result object instance.
 * @class
 * @author   Image Components <info@imagecomponents.net> <https://www.imagecomponents.net>
 * @license  Copyright © ImageComponents 2023
 */
ImgBarCoder.EncodedBarcodeResult = function () {
    /**
    * ImgBarCoder.EncodedBarcodeResult BarcodeBase64 Property
    * @type {String}
    * @property {String} Text Gets the barcode image base 64 value.
    * @param {String} value Sets the barcode image base 64 value.
    * @return {String} Gets the barcode image base 64 value.
    */
    this.BarcodeBase64 = "";
    /**
   * ImgBarCoder.EncodedBarcodeResult BarcodeBase64 Preview Property
   * @type {String}
   * @property {String} Text Gets the barcode image base 64 preview value.
   * @param {String} value Sets the barcode image base 64 preview value.
   * @return {String} Gets the barcode image base 64 preview value.
   */
    this.BarcodeBase64Preview = "";
    /**
  * ImgBarCoder.EncodedBarcodeResult Width Property
  * @type {Number}
  * @property {Number} Text Gets the barcode width value.
  * @param {Number} value Sets the barcode width value.
  * @return {Number} Gets the barcode width value.
  */
    this.BarcodeWidth = 0;
    /**
  * ImgBarCoder.EncodedBarcodeResult Barcode Height Property
  * @type {Number}
  * @property {Number} Text Gets the barcode height value.
  * @param {Number} value Sets the barcode height value.
  * @return {Number} Gets the barcode height value.
  */
    this.BarcodeHeight = 0;
   
};

/*!
 * The Image Components color object class.
 * Creates a new color object instance.
 * @class
 * @author   Image Components <info@imagecomponents.net> <https://www.imagecomponents.net>
 * @license  Copyright © ImageComponents 2023
 */
ImgBarCoder.ICColor = function () {
    /**
     * ImgBarCoder.ICColor A Property
     * @type {Number}
     * @property {Number} A Gets or sets the alpha channel value.
     * @param {Number} value Sets the Alpha channel value.
     * @return {Number} Gets the Alpha channel value.
     */
    this.A = 255;
    /**
    * ImgBarCoder.ICColor R Property
    * @type {Number}
    * @property {Number} R Gets or sets the red channel value.
    * @param {Number} value Sets the Red channel value.
    * @return {Number} Gets the Red channel value.
    */
    this.R = 0;
    /**
    * ImgBarCoder.ICColor G Property
    * @type {Number}
    * @property {Number} G Gets or sets the green channel value.
    * @param {Number} value Sets the Green channel value.
    * @return {Number} Gets the Green channel value.
    */
    this.G = 0;
    /**
    * ImgBarCoder.ICColor B Property
    * @type {Number}
    * @property {Number} B Gets or sets the blue channel value.
    * @param {Number} value Sets the Blue channel value.
    * @return {Number} Gets the Blue channel value.
    */
    this.B = 0;

    var _self = this;
    /**
    * ImgBarCoder.ICColor HexColor Property
    * @type {String}
    * @property {String} HexColor Gets or sets the hex color value.
    * @param {String} value Sets the hex color value.
    * @return {String} Gets the hex color value.
    */
    Object.defineProperty(this, 'HexColor',
        {
            get: function () { return _self.colorToHex(); },
            set: function (value) { _self.hexToColor(value); },
            enumerable: true
        });
};

/**
* ImgBarCoder.ICColor hex to color Method
* Sets the ARGB color values.
* @function
* @param {String} hex The color hex value.
*/
ImgBarCoder.ICColor.prototype.hexToColor = function (hex) {
    var result = [];
    var hexValue = hex.replace("#", "");
    var i = 0;
    var x = 0;
    while (hexValue.length > i + 1) {
        var val = hexValue.substring(i, 2 + x);
        var dec = parseInt(val, 16);
        result.push(dec);
        i += 2;
        x += 2;
    }
    if (result.length == 4) {
        this.A = result[0];
        this.R = result[1];
        this.G = result[2];
        this.B = result[3];
    }
    else if (result.length == 3) {
        this.R = result[0];
        this.G = result[1];
        this.B = result[2];
    }
    return this;
};

/**
* ImgBarCoder.ICColor color to hex Method
* Converts the color value to hex value.
* @function
* @returns {String} The color RGB hex value.
*/
ImgBarCoder.ICColor.prototype.colorToHex = function () {
    var hexChar = ["0", "1", "2", "3", "4", "5", "6", "7", "8", "9", "A", "B", "C", "D", "E", "F"];
    return "#" + (hexChar[(this.R >> 4) & 0x0f] + hexChar[this.R & 0x0f]) +
        (hexChar[(this.G >> 4) & 0x0f] + hexChar[this.G & 0x0f]) +
        (hexChar[(this.B >> 4) & 0x0f] + hexChar[this.B & 0x0f]);
};

/**
* ImgBarCoder.ICColor color to hex ARGB Method
* Converts the color value to hex value.
* @function
* @returns {String} The color ARGB hex value.
*/
ImgBarCoder.ICColor.prototype.colorToHexARGB = function () {
    var hexChar = ["0", "1", "2", "3", "4", "5", "6", "7", "8", "9", "A", "B", "C", "D", "E", "F"];
    return "#" + (hexChar[(this.A >> 4) & 0x0f] + hexChar[this.A & 0x0f]) +
        (hexChar[(this.R >> 4) & 0x0f] + hexChar[this.R & 0x0f]) +
        (hexChar[(this.G >> 4) & 0x0f] + hexChar[this.G & 0x0f]) +
        (hexChar[(this.B >> 4) & 0x0f] + hexChar[this.B & 0x0f]);
};

/*!
 * The Image Components error occurred arguments class.
 * Creates a new error occurred arguments instance.
 * @class
 * @author   Image Components <info@imagecomponents.net> <https://www.imagecomponents.net>
 * @license  Copyright © ImageComponents 2023
 */
ImgBarCoder.ICErrorOccurredArgs = function () {
    /**
    * ImgBarCoder.ICErrorOccurredArgs Control Name Property
    * @readonly
    * @type {String}
    * @property {String} ControlName Gets or sets the control name value.
    * @return {String} Gets the control name value.
    */
    this.ControlName = "";
    /**
    * ImgBarCoder.ICErrorOccurredArgs Method Name Property
    * @readonly
    * @type {String}
    * @property {String} MethodName Gets or sets the method name value.
    * @return {String} Gets the method name value.
    */
    this.MethodName = "";
    /**
    * ImgBarCoder.ICErrorOccurredArgs Error Message Property
    * @readonly
    * @type {String}
    * @property {String} ErrorMessage Gets or sets the error message value.
    * @return {String} Gets the error message value.
    */
    this.ErrorMessage = "";
};
